#ifndef __MARRAY_H__
#define __MARRAY_H__

#include "marray_complex_double.h"

#include "marray_long_double.h"
#include "marray_double.h"
#include "marray_float.h"

#include "marray_ulong.h"
#include "marray_long.h"

#include "marray_uint.h"
#include "marray_int.h"

#include "marray_ushort.h"
#include "marray_short.h"

#include "marray_uchar.h"
#include "marray_char.h"


#endif /* __MARRAY_H__ */
